@@ -122,6 +122,10 @@ This module and other memcached client libraries have the same behavior.
     1
     >>> mc.get_multi(["a", "b", "c"])
     {'a': 122228, 'c': 'value'}
+    >>> mc.delete("a")
+    1
+    >>> mc.get("a") is None
+    True
 
 """
 
@@ -133,7 +137,7 @@ __maintainer__ = __author__
 __email__ = "dahlia@lunant.net"
 __copyright__ = "Copyright (c) 2010 Lunant <http://lunant.net/>"
 __license__ = "MIT License"
-__version__ = "1.0"
+__version__ = "1.0.1"
 
 
 class Client(object):
@@ -142,6 +146,8 @@ class Client(object):
 
     """
 
+    __slots__ = "dictionary",
+
     def __init__(self, *args, **kwargs):
         """Does nothing. It takes no or any arguments, but they are just for
         compatibility so ignored.
@@ -159,7 +165,7 @@ class Client(object):
 
     def delete(self, key, time=0):
         """Deletes the `key` from the dictionary."""
-        if key in dictionary:
+        if key in self.dictionary:
             if int(time) < 1:
                 del self.dictionary[key]
                 return 1
